from setuptools import setup

setup(name='GML_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['GML_distributions'],
      author='Siqi Huang',
      author_email='siqi.huang@boehringer-ingelheim.com',
      zip_safe=False)
